##############################################################################
#
# Copyright (c) 2002 Zope Foundation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE
#
##############################################################################

from __future__ import absolute_import

# BBB
from AuthEncoding.AuthEncoding import MySQLDigestScheme  # NOQA
from AuthEncoding.AuthEncoding import PasswordEncryptionScheme
from AuthEncoding.AuthEncoding import SHADigestScheme
from AuthEncoding.AuthEncoding import SSHADigestScheme
from AuthEncoding.AuthEncoding import constant_time_compare
from AuthEncoding.AuthEncoding import is_encrypted
from AuthEncoding.AuthEncoding import listSchemes
from AuthEncoding.AuthEncoding import pw_encode
from AuthEncoding.AuthEncoding import pw_encrypt
from AuthEncoding.AuthEncoding import pw_validate
from AuthEncoding.AuthEncoding import registerScheme


# Bogosity on various platforms due to ITAR restrictions
try:
    from AuthEncoding.AuthEncoding import CryptDigestScheme  # NOQA
except ImportError:
    pass



##############################################################################
#
# Copyright (c) 2002 Zope Foundation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Access control package.
"""

from zope.deferredimport import deprecated

# BBB
from AccessControl.users import BasicUser
from AccessControl.users import NullUnrestrictedUser
from AccessControl.users import SimpleUser
from AccessControl.users import SpecialUser
from AccessControl.users import UnrestrictedUser as Super
from AccessControl.users import User
from AccessControl.users import _remote_user_mode
from AccessControl.users import absattr
from AccessControl.users import addr_match
from AccessControl.users import domainSpecMatch
from AccessControl.users import emergency_user
from AccessControl.users import host_match
from AccessControl.users import nobody
from AccessControl.users import readUserAccessFile
from AccessControl.users import reqattr
from AccessControl.users import rolejoin
from AccessControl.users import system


from AccessControl.users import UnrestrictedUser # noqa isort:skip


deprecated(
    "The standard Zope user folder implementation has moved to "
    "OFS.userfolder.  Please depend on Zope2 and import from "
    "OFS.userfolder or use the new minimal "
    "user folder classes from AccessControl.userfolder.",
    BasicUserFolder='OFS.userfolder:BasicUserFolder',
    manage_addUserFolder='OFS.userfolder:manage_addUserFolder',
    UserFolder='OFS.userfolder:UserFolder',
)



##############################################################################
#
# Copyright (c) 2002 Zope Foundation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE
#
##############################################################################
"""Add security system support to Document Templates
"""

from zope.deferredimport import deprecated


deprecated(
    "Please import from DocumentTemplate.security. This backward "
    "compatibility shim will be removed in AccessControl version 5.",
    DTMLSecurityAPI='DocumentTemplate.security:DTMLSecurityAPI',
    RestrictedDTML='DocumentTemplate.security:RestrictedDTML',
)



##############################################################################
#
# Copyright (c) 2002 Zope Foundation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE
#
##############################################################################
"""Support for owned objects
"""

from zope.deferredimport import deprecated

# BBB
from AccessControl.owner import EditUnowned
from AccessControl.owner import EmergencyUserCannotOwn
from AccessControl.owner import UnownableOwner
from AccessControl.owner import absattr
from AccessControl.owner import ownableFilter
from AccessControl.owner import ownerInfo


deprecated(
    "The Owned class has moved to OFS.owner. This compatibility "
    "shim will be removed in AccessControl version 5. Please "
    "depend on Zope2 and import from OFS.owner or use the "
    "new minimal Owned class from AccessControl.owner.",
    Owned='OFS.owner:Owned',
)



##############################################################################
#
# Copyright (c) 2002 Zope Foundation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE
#
##############################################################################
"""Access control support
"""

from zope.deferredimport import deprecated

# BBB
from AccessControl.rolemanager import DEFAULTMAXLISTUSERS
from AccessControl.rolemanager import _isBeingUsedAsAMethod
from AccessControl.rolemanager import _isNotBeingUsedAsAMethod
from AccessControl.rolemanager import class_attrs
from AccessControl.rolemanager import class_dict
from AccessControl.rolemanager import classattr
from AccessControl.rolemanager import gather_permissions
from AccessControl.rolemanager import instance_attrs
from AccessControl.rolemanager import instance_dict
from AccessControl.rolemanager import reqattr


deprecated(
    "RoleManager has moved to OFS.role. Please "
    "depend on Zope and import from OFS.role or use the new minimal "
    "RoleManager class from AccessControl.rolemanager. "
    "This backward compatibility shim will be removed in AccessControl "
    "version 5.",
    RoleManager='OFS.role:RoleManager',
)
